@@ -31,6 +31,7 @@
 #include "Class.hxx"
 #include "String.hxx"
 #include "Object.hxx"
+#include "Exception.hxx"
 #include "fs/AllocatedPath.hxx"
 #include "fs/Limits.hxx"
 
@@ -54,13 +55,9 @@ Java::File::ToAbsolutePath(JNIEnv *env, jobject _file) noexcept
 	LocalObject file(env, _file);
 
 	const jstring path = getAbsolutePath(env, file);
-	if (path == nullptr) {
-		env->ExceptionClear();
+	if (DiscardException(env) || path == nullptr)
 		return nullptr;
-	}
 
 	Java::String path2(env, path);
-	char buffer[MPD_PATH_MAX];
-	path2.CopyTo(env, buffer, sizeof(buffer));
-	return AllocatedPath::FromUTF8(buffer);
+	return AllocatedPath::FromFS(path2.ToString());
 }
