@@ -36,12 +36,13 @@
 #include "util/StringStrip.hxx"
 #include "util/StringView.hxx"
 #include "util/CharUtil.hxx"
+#include "Version.h"
 
 #include <curl/curl.h>
 
 #include <algorithm>
+#include <cassert>
 
-#include <assert.h>
 #include <string.h>
 
 CurlRequest::CurlRequest(CurlGlobal &_global,
@@ -76,7 +77,7 @@ CurlRequest::Start()
 {
 	assert(!registered);
 
-	global.Add(easy.Get(), *this);
+	global.Add(*this);
 	registered = true;
 }
 
@@ -94,7 +95,7 @@ CurlRequest::Stop() noexcept
 	if (!registered)
 		return;
 
-	global.Remove(easy.Get());
+	global.Remove(*this);
 	registered = false;
 }
 
@@ -135,7 +136,7 @@ CurlRequest::FinishHeaders()
 	state = State::BODY;
 
 	long status = 0;
-	curl_easy_getinfo(easy.Get(), CURLINFO_RESPONSE_CODE, &status);
+	easy.GetInfo(CURLINFO_RESPONSE_CODE, &status);
 
 	handler.OnHeaders(status, std::move(headers));
 }
